@@ -210,13 +210,13 @@ static void UnlockMonitor(Monitor * monitor)
 }
 
 /****************************************************************************
- **
- *F WaitForMonitor(monitor) . . . . . .. . wait for a monitor to be ready
- **
- ** 'WaitForMonitor' waits for the monitor to be signaled by another
- ** thread. The monitor must be locked upon entry and will be locked
- ** again upon exit.
- */
+**
+*F WaitForMonitor(monitor) . . . . . .. . wait for a monitor to be ready
+**
+** 'WaitForMonitor' waits for the monitor to be signaled by another
+** thread. The monitor must be locked upon entry and will be locked
+** again upon exit.
+*/
 
 static void WaitForMonitor(Monitor * monitor)
 {
@@ -275,21 +275,21 @@ void UnlockMonitors(UInt count, Monitor ** monitors)
 
 
 /****************************************************************************
- **
- *F WaitForAnyMonitor(count, monitors) . . wait for a monitor to be ready
- **
- ** 'WaitForAnyMonitor' waits for any one of the monitors in the list to
- ** be signaled. The function returns when any of them is signaled via
- ** 'SignalMonitor'. The first argument is the number of monitors in the
- ** list, the second argument is an array of monitor pointers.
- **
- ** The list must be sorted by 'MonitorOrder' before passing it to the
- ** function; all monitors must also be locked before calling the function
- ** by calling 'LockMonitors'.
- **
- ** Upon return, all monitors but the one that was signaled will be
- ** unlocked.
- */
+**
+*F WaitForAnyMonitor(count, monitors) . . wait for a monitor to be ready
+**
+** 'WaitForAnyMonitor' waits for any one of the monitors in the list to
+** be signaled. The function returns when any of them is signaled via
+** 'SignalMonitor'. The first argument is the number of monitors in the
+** list, the second argument is an array of monitor pointers.
+**
+** The list must be sorted by 'MonitorOrder' before passing it to the
+** function; all monitors must also be locked before calling the function
+** by calling 'LockMonitors'.
+**
+** Upon return, all monitors but the one that was signaled will be
+** unlocked.
+*/
 
 UInt WaitForAnyMonitor(UInt count, Monitor ** monitors)
 {
@@ -320,7 +320,7 @@ UInt WaitForAnyMonitor(UInt count, Monitor ** monitors)
         if (monitors[i] == monitor) {
             RemoveWaitList(monitors[i], &nodes[i]);
             result = i;
-            /* keep it locked for further processing by caller */
+            // keep it locked for further processing by caller
         }
         else {
             RemoveWaitList(monitors[i], &nodes[i]);
@@ -334,13 +334,13 @@ UInt WaitForAnyMonitor(UInt count, Monitor ** monitors)
 }
 
 /****************************************************************************
- **
- *F SignalMonitor(monitor) . . . . . . . . . . send a signal to a monitor
- **
- ** Sends a signal to a monitor that is being waited for by another thread.
- ** The monitor must be locked upon entry and will be locked again upon
- ** exit. If no thread is waiting for the monitor, no operation will occur.
- */
+**
+*F SignalMonitor(monitor) . . . . . . . . . . send a signal to a monitor
+**
+** Sends a signal to a monitor that is being waited for by another thread.
+** The monitor must be locked upon entry and will be locked again upon
+** exit. If no thread is waiting for the monitor, no operation will occur.
+*/
 
 void SignalMonitor(Monitor * monitor)
 {
@@ -383,7 +383,7 @@ static int GetThreadID(const char * funcname, Obj thread)
 
 
 
-/* TODO: register globals */
+// TODO: register globals
 static Obj             FirstKeepAlive;
 static Obj             LastKeepAlive;
 static pthread_mutex_t KeepAliveLock;
@@ -488,7 +488,7 @@ static Obj FuncCreateThread(Obj self, Obj funcargs)
         ErrorMayQuit("CreateThread: <func> expects %d arguments, but got %d", NARG_FUNC(func), n-1);
     templist = NEW_PLIST(T_PLIST, n);
     SET_LEN_PLIST(templist, n);
-    SET_REGION(templist, NULL); /* make it public */
+    SET_REGION(templist, NULL); // make it public
     for (i = 1; i <= n; i++)
         SET_ELM_PLIST(templist, i, ELM_PLIST(funcargs, i));
     thread = RunThread(ThreadedInterpreter, KeepAlive(templist));
@@ -997,7 +997,7 @@ static void WaitChannel(Channel * channel)
 
 static void ExpandChannel(Channel * channel)
 {
-    /* Growth ratio should be less than the golden ratio */
+    // Growth ratio should be less than the golden ratio
     const UInt oldCapacity = channel->capacity;
     const UInt newCapacity = ((oldCapacity * 25 / 16) | 1) + 1;
     GAP_ASSERT(newCapacity > oldCapacity);
@@ -1179,14 +1179,14 @@ static Obj ReceiveAnyChannel(Obj channelList, int with_index)
         if (p >= count)
             p = 0;
     }
-    if (i < count) /* found a channel with data */
+    if (i < count) // found a channel with data
     {
         p = i;
         for (i = 0; i < count; i++)
             if (i != p)
                 UnlockMonitor(monitors[i]);
     }
-    else /* all channels are empty */
+    else // all channels are empty
         for (;;) {
             for (i = 0; i < count; i++)
                 channels[i]->waiting++;
@@ -2246,7 +2246,7 @@ static Obj FuncORDERED_WRITE(Obj self, Obj obj)
 
 static Obj FuncDEFAULT_SIGINT_HANDLER(Obj self)
 {
-    /* do nothing */
+    // do nothing
     return (Obj)0;
 }
 
@@ -2317,7 +2317,7 @@ void InitSignals(void)
     sigaddset(&GAPSignals, SIGWINCH);
 #endif
     pthread_sigmask(SIG_BLOCK, &GAPSignals, NULL);
-    /* Run a timer signal every 10 ms, i.e. 100 times per second */
+    // Run a timer signal every 10 ms, i.e. 100 times per second
     timer.it_interval.tv_sec = 0;
     timer.it_interval.tv_usec = 10000;
     timer.it_value.tv_sec = 0;
@@ -2673,11 +2673,11 @@ static Int InitKernel(StructInitInfo * module)
 */
 static Int InitLibrary(StructInitInfo * module)
 {
-    /* init filters and functions                                          */
+    // init filters and functions
     InitGVarFuncsFromTable(GVarFuncs);
     SetGVar(&MAX_INTERRUPTGVar, INTOBJ_INT(MAX_INTERRUPT));
     MakeReadOnlyGVar(GVarName("MAX_INTERRUPT"));
-    /* define signal handler values */
+    // define signal handler values
     RNAM_SIGINT = RNamName("SIGINT");
     RNAM_SIGCHLD = RNamName("SIGCHLD");
     RNAM_SIGVTALRM = RNamName("SIGVTALRM");
@@ -2685,7 +2685,7 @@ static Int InitLibrary(StructInitInfo * module)
     RNAM_SIGWINCH = RNamName("SIGWINCH");
 #endif
 
-    /* synchronization */
+    // synchronization
     pthread_mutex_init(&KeepAliveLock, NULL);
 
     ExportAsConstantGVar(MAX_THREADS);
