@@ -17,7 +17,7 @@
 **  connects as client to a specified socket.
 **
 **  At this level, we provide the two interfaces separately. For each we have
-**  an integer identifer for each open connection, and creation, read and
+**  an integer identifier for each open connection, and creation, read and
 **  write functions, and possibly some sort of probe function.
 **
 */
@@ -32,6 +32,8 @@
 #include "modules.h"
 #include "stringobj.h"
 #include "sysenv.h"
+#include "sysfiles.h"
+#include "sysopt.h"
 
 #include "hpc/thread.h"
 
@@ -51,11 +53,11 @@
 
 #ifdef HAVE_OPENPTY
   #if defined(HAVE_UTIL_H)
-    #include <util.h>     /* for openpty() on Mac OS X, OpenBSD and NetBSD */
+    #include <util.h>     // for openpty() on macOS, OpenBSD and NetBSD
   #elif defined(HAVE_LIBUTIL_H)
-    #include <libutil.h>  /* for openpty() on FreeBSD */
+    #include <libutil.h>  // for openpty() on FreeBSD
   #elif defined(HAVE_PTY_H)
-    #include <pty.h>      /* for openpty() on Cygwin, Interix, OSF/1 4 and 5 */
+    #include <pty.h>      // for openpty() on Cygwin, Interix, OSF/1 4 and 5
   #endif
 #endif
 
@@ -64,30 +66,37 @@
 #include <spawn.h>
 #endif
 
+#ifdef SYS_IS_CYGWIN32
+#include <process.h>
+#endif
+
+#ifdef HAVE_SELECT
+#include <sys/time.h>
+#endif
 
 // LOCKING
 // In HPC-GAP, be sure to HashLock PtyIOStreams before accessing any of
 // the IOStream related variables, including FreeptyIOStreams
 
 typedef struct {
-  pid_t childPID;   /* Also used as a link to make a linked free list */
-  int ptyFD;      /* GAP reading from external prog */
+  pid_t childPID;   // Also used as a link to make a linked free list
+  int ptyFD;      // GAP reading from external prog
   int inuse;      /* we need to scan all the "live" structures when we have
                      had SIGCHLD so, for now, we just walk the array for
                      the ones marked in use */
   int changed;    /* set non-zero by the signal handler if our child has
                      done something -- stopped or exited */
-  int status;     /* status from wait3 -- meaningful only if changed is 1 */
-  int blocked;    /* we have already reported a problem, which is still there */
+  int status;     // status from wait3 -- meaningful only if changed is 1
+  int blocked;    // we have already reported a problem, which is still there
   int alive;      /* gets set after waiting for a child actually fails
                      implying that the child has vanished under our noses */
 } PtyIOStream;
 
 enum {
-    /* maximal number of pseudo ttys we will allocate */
+    // maximal number of pseudo ttys we will allocate
     MAX_PTYS = 64,
 
-    /* maximal length of argument string for CREATE_PTY_IOSTREAM */
+    // maximal length of argument string for CREATE_PTY_IOSTREAM
     MAX_ARGS = 1000
 };
 
@@ -154,7 +163,7 @@ static void KillChild(UInt stream)
 
 static UInt OpenPty(int * parent, int * child)
 {
-    /* openpty is available on OpenBSD, NetBSD and FreeBSD, Mac OS X,
+    /* openpty is available on OpenBSD, NetBSD and FreeBSD, macOS,
        Cygwin, Interix, OSF/1 4 and 5, and glibc (since 1998), and hence
        on most modern Linux systems. See also:
        https://www.gnu.org/software/gnulib/manual/html_node/openpty.html */
@@ -170,7 +179,7 @@ static UInt OpenPty(int * parent, int * child)
        UNIX system; indeed, according to gnulib, it is available on at
        least the following systems:
          - glibc >= 2.2.1 (released January 2001; but is a stub on GNU/Hurd),
-         - Mac OS X >= 10.4 (released April 2005),
+         - macOS >= 10.4 (released April 2005),
          - FreeBSD >= 5.1 (released June 2003),
          - NetBSD >= 3.0 (released December 2005),
          - AIX >= 5.2 (released October 2002),
@@ -231,7 +240,7 @@ static UInt OpenPty(int * parent, int * child)
 **
 *F  StartChildProcess( <dir>, <name>, <args> )
 **  Start a subprocess using ptys. Returns the stream number of the IOStream
-**  that is connected to the new processs
+**  that is connected to the new process
 */
 
 
@@ -408,21 +417,21 @@ static int posix_spawn_with_dir(pid_t *                      pid,
 static Int
 StartChildProcess(const Char * dir, const Char * prg, Char * args[])
 {
-    int child; /* pipe to child                   */
+    int child; // pipe to child
     Int stream;
 
-    struct termios tst; /* old and new terminal state      */
+    struct termios tst; // old and new terminal state
 
     HashLock(PtyIOStreams);
 
-    /* Get a stream record */
+    // Get a stream record
     stream = NewStream();
     if (stream == -1) {
         HashUnlock(PtyIOStreams);
         return -1;
     }
 
-    /* open pseudo terminal for communication with gap */
+    // open pseudo terminal for communication with gap
     if (OpenPty(&PtyIOStreams[stream].ptyFD, &child)) {
         PErr("StartChildProcess: open pseudo tty failed");
         FreeStream(stream);
@@ -430,7 +439,7 @@ StartChildProcess(const Char * dir, const Char * prg, Char * args[])
         return -1;
     }
 
-    /* Now fiddle with the terminal sessions on the pty */
+    // Now fiddle with the terminal sessions on the pty
     if (tcgetattr(child, &tst) == -1) {
         PErr("StartChildProcess: tcgetattr on child pty failed");
         goto cleanup;
@@ -447,14 +456,14 @@ StartChildProcess(const Char * dir, const Char * prg, Char * args[])
         goto cleanup;
     }
 
-    /* set input to non blocking operation */
-    /* Not any more */
+    // set input to non blocking operation
+    // Not any more
 
     PtyIOStreams[stream].inuse = 1;
     PtyIOStreams[stream].alive = 1;
     PtyIOStreams[stream].blocked = 0;
     PtyIOStreams[stream].changed = 0;
-    /* fork */
+    // fork
 #ifdef HAVE_POSIX_SPAWN
     posix_spawn_file_actions_t file_actions;
 
@@ -498,7 +507,7 @@ StartChildProcess(const Char * dir, const Char * prg, Char * args[])
 #else
     PtyIOStreams[stream].childPID = fork();
     if (PtyIOStreams[stream].childPID == 0) {
-        /* Set up the child */
+        // Set up the child
         close(PtyIOStreams[stream].ptyFD);
         if (dup2(child, 0) == -1)
             _exit(-1);
@@ -518,14 +527,14 @@ StartChildProcess(const Char * dir, const Char * prg, Char * args[])
 
         execv(prg, args);
 
-        /* This should never happen */
+        // This should never happen
         close(child);
         _exit(1);
     }
 #endif
 
-    /* Now we're back in the parent */
-    /* check if the fork was successful */
+    // Now we're back in the parent
+    // check if the fork was successful
     if (PtyIOStreams[stream].childPID == -1) {
         PErr("StartChildProcess: cannot fork to subprocess");
         goto cleanup;
@@ -546,12 +555,254 @@ cleanup:
 }
 
 
+#ifndef GAP_DISABLE_SUBPROCESS_CODE
+
+/****************************************************************************
+**
+*F  SyExecuteProcess( <dir>, <prg>, <in>, <out>, <args> ) . . . . new process
+**
+**  Start  <prg> in  directory <dir>  with  standard input connected to <in>,
+**  standard  output  connected to <out>   and arguments.  No  path search is
+**  performed, the return  value of the process  is returned if the operation
+**  system supports such a concept.
+*/
+
+/****************************************************************************
+**
+*f  SyExecuteProcess( <dir>, <prg>, <in>, <out>, <args> )
+*/
+#if defined(HAVE_FORK) || defined(HAVE_VFORK)
+
+#ifndef WEXITSTATUS
+#define WEXITSTATUS(stat_val) ((unsigned)(stat_val) >> 8)
+#endif
+#ifndef WIFEXITED
+#define WIFEXITED(stat_val) (((stat_val)&255) == 0)
+#endif
+
+#ifdef SYS_IS_CYGWIN32
+
+static UInt
+SyExecuteProcess(Char * dir, Char * prg, Int in, Int out, Char * args[])
+{
+    int savestdin, savestdout;
+    Int tin, tout;
+    int res;
+
+    // change the working directory
+    if (chdir(dir) == -1)
+        return -1;
+
+    // if <in> is -1 open "/dev/null"
+    if (in == -1)
+        tin = open("/dev/null", O_RDONLY);
+    else
+        tin = SyBufFileno(in);
+    if (tin == -1)
+        return -1;
+
+    // if <out> is -1 open "/dev/null"
+    if (out == -1)
+        tout = open("/dev/null", O_WRONLY);
+    else
+        tout = SyBufFileno(out);
+    if (tout == -1) {
+        if (in == -1)
+            close(tin);
+        return -1;
+    }
+
+    // set standard input to <in>, standard output to <out>
+    savestdin = -1;    // Just to please the compiler
+    if (tin != 0) {
+        savestdin = dup(0);
+        if (savestdin == -1 || dup2(tin, 0) == -1) {
+            if (out == -1)
+                close(tout);
+            if (in == -1)
+                close(tin);
+            return -1;
+        }
+        fcntl(0, F_SETFD, 0);
+    }
+
+    if (tout != 1) {
+        savestdout = dup(1);
+        if (savestdout == -1 || dup2(tout, 1) == -1) {
+            if (tin != 0) {
+                close(0);
+                dup2(savestdin, 0);
+                close(savestdin);
+            }
+            if (out == -1)
+                close(tout);
+            if (in == -1)
+                close(tin);
+            return -1;
+        }
+        fcntl(1, F_SETFD, 0);
+    }
+
+    FreezeStdin = 1;
+    // now try to execute the program
+    res = spawnve(_P_WAIT, prg, (const char * const *)args,
+                  (const char * const *)environ);
+
+    // Now repair the open file descriptors:
+    if (tout != 1) {
+        close(1);
+        dup2(savestdout, 1);
+        close(savestdout);
+    }
+    if (tin != 0) {
+        close(0);
+        dup2(savestdin, 0);
+        close(savestdin);
+    }
+    if (out == -1)
+        close(tout);
+    if (in == -1)
+        close(tin);
+
+    FreezeStdin = 0;
+
+    // Report result:
+    if (res < 0)
+        return -1;
+    return WEXITSTATUS(res);
+}
+
+#else
+
+typedef void sig_handler_t(int);
+
+static void NullSignalHandler(int scratch)
+{
+}
+
+static UInt
+SyExecuteProcess(Char * dir, Char * prg, Int in, Int out, Char * args[])
+{
+    pid_t pid;    // process id
+    pid_t wait_pid;
+    int   status;    // do not use `Int'
+    Int   tin;       // temp in
+    Int   tout;      // temp out
+    sig_handler_t * volatile func2;
+
+
+    // turn off the SIGCHLD handling, so that we can be sure to collect this
+    // child `After that, we call the old signal handler, in case any other
+    // children have died in the meantime. This resets the handler
+
+    func2 = signal(SIGCHLD, SIG_DFL);
+
+    // This may return SIG_DFL (0x0) or SIG_IGN (0x1) if the previous handler
+    // was set to the default or 'ignore'. In these cases (or if SIG_ERR is
+    // returned), just use a null signal handler - the default on most systems
+    // is to do nothing
+    if (func2 == SIG_ERR || func2 == SIG_DFL || func2 == SIG_IGN)
+        func2 = &NullSignalHandler;
+
+    // clone the process
+    pid = fork();
+    if (pid == -1) {
+        return -1;
+    }
+
+    // we are the parent
+    if (pid != 0) {
+        // Stop trying to read input
+        FreezeStdin = 1;
+
+        // ignore a CTRL-C
+        struct sigaction sa;
+        struct sigaction oldsa;
+
+        sa.sa_handler = SIG_IGN;
+        sigemptyset(&(sa.sa_mask));
+        sa.sa_flags = 0;
+        sigaction(SIGINT, &sa, &oldsa);
+
+        // wait for some action
+        wait_pid = waitpid(pid, &status, 0);
+        FreezeStdin = 0;
+        sigaction(SIGINT, &oldsa, NULL);
+        (*func2)(SIGCHLD);
+        if (wait_pid == -1) {
+            return -1;
+        }
+        if (WIFSIGNALED(status)) {
+            return -1;
+        }
+        return WEXITSTATUS(status);
+    }
+
+    // we are the child
+    else {
+
+        // change the working directory
+        if (chdir(dir) == -1) {
+            _exit(-1);
+        }
+
+        // if <in> is -1 open "/dev/null"
+        if (in == -1) {
+            tin = open("/dev/null", O_RDONLY);
+        }
+        else {
+            tin = SyBufFileno(in);
+        }
+        if (tin == -1) {
+            _exit(-1);
+        }
+
+        // if <out> is -1 open "/dev/null"
+        if (out == -1) {
+            tout = open("/dev/null", O_WRONLY);
+        }
+        else {
+            tout = SyBufFileno(out);
+        }
+        if (tout == -1) {
+            _exit(-1);
+        }
+
+        // set standard input to <in>, standard output to <out>
+        if (tin != 0) {
+            if (dup2(tin, 0) == -1) {
+                _exit(-1);
+            }
+        }
+        fcntl(0, F_SETFD, 0);
+
+        if (tout != 1) {
+            if (dup2(tout, 1) == -1) {
+                _exit(-1);
+            }
+        }
+        fcntl(1, F_SETFD, 0);
+
+        // now try to execute the program
+        execve(prg, args, environ);
+        _exit(-1);
+    }
+
+    // this should not happen
+    return -1;
+}
+#endif
+
+#endif
+
+#endif    // !GAP_DISABLE_SUBPROCESS_CODE
+
 // This function assumes that the caller invoked HashLock(PtyIOStreams).
 // It unlocks just before throwing any error.
 static void HandleChildStatusChanges(UInt pty)
 {
-    /* common error handling, when we are asked to read or write to a stopped
-       or dead child */
+    // common error handling, when we are asked to read or write to a stopped
+    // or dead child
     if (PtyIOStreams[pty].alive == 0) {
         PtyIOStreams[pty].changed = 0;
         PtyIOStreams[pty].blocked = 0;
@@ -588,7 +839,7 @@ static Obj FuncCREATE_PTY_IOSTREAM(Obj self, Obj dir, Obj prog, Obj args)
         allargs[i] = ELM_LIST(args, i);
         ConvString(allargs[i]);
     }
-    /* From here we cannot afford to have a garbage collection */
+    // From here we cannot afford to have a garbage collection
     argv[0] = CSTR_STRING(prog);
     for (i = 1; i <= len; i++) {
         argv[i] = CSTR_STRING(allargs[i]);
@@ -605,11 +856,10 @@ static Obj FuncCREATE_PTY_IOSTREAM(Obj self, Obj dir, Obj prog, Obj args)
 
 static Int ReadFromPty2(UInt stream, Char * buf, Int maxlen, UInt block)
 {
-    /* read at most maxlen bytes from stream, into buf.
-      If block is non-zero then wait for at least one byte
-      to be available. Otherwise don't. Return the number of
-      bytes read, or -1 for error. A blocking return having read zero bytes
-      definitely indicates an end of file */
+    // read at most maxlen bytes from stream, into buf. If block is non-zero
+    // then wait for at least one byte to be available. Otherwise don't.
+    // Return the number of bytes read, or -1 for error. A blocking return
+    // having read zero bytes definitely indicates an end of file
 
     Int nread = 0;
     int ret;
@@ -736,7 +986,7 @@ static Obj FuncKILL_CHILD_IOSTREAM(Obj self, Obj stream)
 {
     UInt pty = HashLockStreamIfAvailable(stream);
 
-    /* Don't check for child having changes status */
+    // Don't check for child having changes status
     KillChild(pty);
 
     HashUnlock(PtyIOStreams);
@@ -747,7 +997,7 @@ static Obj FuncSIGNAL_CHILD_IOSTREAM(Obj self, Obj stream, Obj sig)
 {
     UInt pty = HashLockStreamIfAvailable(stream);
 
-    /* Don't check for child having changes status */
+    // Don't check for child having changes status
     SignalChild(pty, INT_INTOBJ(sig));
 
     HashUnlock(PtyIOStreams);
@@ -758,12 +1008,12 @@ static Obj FuncCLOSE_PTY_IOSTREAM(Obj self, Obj stream)
 {
     UInt pty = HashLockStreamIfAvailable(stream);
 
-    /* Close down the child */
+    // Close down the child
     int status;
+    kill(PtyIOStreams[pty].childPID, SIGTERM);
     int retcode = close(PtyIOStreams[pty].ptyFD);
     if (retcode)
         Pr("Strange close return code %d\n", retcode, 0);
-    kill(PtyIOStreams[pty].childPID, SIGTERM);
     // GAP (or another library) might wait on this PID before
     // we handle it. If that happens, waitpid will return -1.
     retcode = waitpid(PtyIOStreams[pty].childPID, &status, WNOHANG);
@@ -804,6 +1054,47 @@ static Obj FuncFD_OF_IOSTREAM(Obj self, Obj stream)
     return result;
 }
 
+static Obj
+FuncExecuteProcess(Obj self, Obj dir, Obj prg, Obj in, Obj out, Obj args)
+{
+    Obj    ExecArgs[1024];
+    Char * ExecCArgs[1024];
+
+    Obj tmp;
+    Int res;
+    Int i;
+
+    RequireStringRep(SELF_NAME, dir);
+    RequireStringRep(SELF_NAME, prg);
+    Int iin = GetSmallInt(SELF_NAME, in);
+    Int iout = GetSmallInt(SELF_NAME, out);
+    RequireSmallList(SELF_NAME, args);
+
+    // create an argument array
+    for (i = 1; i <= LEN_LIST(args); i++) {
+        if (i == 1023)
+            break;
+        tmp = ELM_LIST(args, i);
+        RequireStringRep(SELF_NAME, tmp);
+        ExecArgs[i] = tmp;
+    }
+    ExecCArgs[0] = CSTR_STRING(prg);
+    ExecCArgs[i] = 0;
+    for (i--; 0 < i; i--) {
+        ExecCArgs[i] = CSTR_STRING(ExecArgs[i]);
+    }
+    if (SyWindow && out == INTOBJ_INT(1))    // standard output
+        syWinPut(INT_INTOBJ(out), "@z", "");
+
+    // execute the process
+    res = SyExecuteProcess(CSTR_STRING(dir), CSTR_STRING(prg), iin, iout,
+                           ExecCArgs);
+
+    if (SyWindow && out == INTOBJ_INT(1))    // standard output
+        syWinPut(INT_INTOBJ(out), "@mAgIc", "");
+    return res == 255 ? Fail : INTOBJ_INT(res);
+}
+
 #else // !defined(GAP_DISABLE_SUBPROCESS_CODE)
 
 int CheckChildStatusChanged(int childPID, int status)
@@ -856,6 +1147,12 @@ static Obj FuncFD_OF_IOSTREAM(Obj self, Obj stream)
     return Fail;
 }
 
+static Obj
+FuncExecuteProcess(Obj self, Obj dir, Obj prg, Obj in, Obj out, Obj args)
+{
+    return Fail;
+}
+
 #endif
 
 
@@ -882,12 +1179,13 @@ static StructGVarFunc GVarFuncs[] = {
 #ifdef HPCGAP
     GVAR_FUNC_0ARGS(DEFAULT_SIGCHLD_HANDLER),
 #endif
+    GVAR_FUNC_5ARGS(ExecuteProcess, dir, prg, in, out, args),
 
     { 0, 0, 0, 0, 0 }
 };
-  
-/* FIXME/TODO: should probably do some checks preSave for open files etc and
-   refuse to save if any are found */
+
+// FIXME/TODO: should probably do some checks preSave for open files etc and
+// refuse to save if any are found
 
 /****************************************************************************
 **
@@ -905,13 +1203,13 @@ static Int InitKernel(StructInitInfo * module)
     FreePtyIOStreams = MAX_PTYS - 1;
 
 #if !defined(HPCGAP)
-    /* Set up the trap to detect future dying children */
+    // Set up the trap to detect future dying children
     signal(SIGCHLD, ChildStatusChanged);
 #endif
 
 #endif
 
-    /* init filters and functions                                          */
+    // init filters and functions
     InitHdlrFuncsFromTable(GVarFuncs);
 
     return 0;
@@ -923,7 +1221,7 @@ static Int InitKernel(StructInitInfo * module)
 */
 static Int InitLibrary(StructInitInfo * module)
 {
-    /* init filters and functions                                          */
+    // init filters and functions
     InitGVarFuncsFromTable(GVarFuncs);
 
     return 0;
